Package: tidypredict
Title: Run Predictions Inside the Database
Version: 0.5
Authors@R: 
    c(
      person("Edgar", "Ruiz", email = "edgar@posit.co", role = c("aut", "cre")),
      person("Max", "Kuhn", email = "max@posit.co", role = c("aut"))
    )
Description: It parses a fitted 'R' model object, and returns a formula in
    'Tidy Eval' code that calculates the predictions.  It works with
    several databases back-ends because it leverages 'dplyr' and 'dbplyr'
    for the final 'SQL' translation of the algorithm. It currently
    supports lm(), glm(), randomForest(), ranger(), earth(),
    xgb.Booster.complete(), cubist(), and ctree() models.
License: MIT + file LICENSE
URL: https://tidypredict.tidymodels.org,
        https://github.com/tidymodels/tidypredict
BugReports: https://github.com/tidymodels/tidypredict/issues
Depends: R (>= 3.1)
Imports: dplyr (>= 0.7), generics, knitr, purrr, rlang, tibble, tidyr
Suggests: covr, Cubist, DBI, dbplyr, earth (>= 5.1.2), methods,
        mlbench, modeldata, nycflights13, parsnip, partykit,
        randomForest, ranger, rmarkdown, RSQLite, testthat (>= 3.0.0),
        xgboost, yaml
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Encoding: UTF-8
RoxygenNote: 7.2.3
Config/testthat/edition: 3
Author: Edgar Ruiz [aut, cre],
  Max Kuhn [aut]
Maintainer: Edgar Ruiz <edgar@posit.co>
Built: R 4.4.0; ; 2024-04-28 04:31:19 UTC; unix
