Package: tidypredict
Version: 0.2.0
Title: Run Predictions Inside the Database
Description: It parses a fitted 'R' model object, and returns a formula
    in 'Tidy Eval' code that calculates the predictions.
    It works with several databases back-ends because it leverages 'dplyr'
    and 'dbplyr' for the final 'SQL' translation of the algorithm. It currently
    supports lm(), glm(), randomForest() and ranger() models. 
Authors@R: 
    person("Edgar", "Ruiz", email = "edgar@rstudio.com", role = c("aut", "cre"))
Depends: R (>= 3.1)
Imports: dplyr(>= 0.7), rlang, purrr, tibble, tidyr
Suggests: dbplyr, testthat, randomForest, ranger, knitr, rmarkdown,
        nycflights13, RSQLite, methods, DBI
License: GPL-3
URL: http://tidypredict.netlify.com/
BugReports: https://github.com/edgararuiz/tidypredict/issues
RoxygenNote: 6.0.1
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2018-02-25 22:55:08 UTC; edgar
Author: Edgar Ruiz [aut, cre]
Maintainer: Edgar Ruiz <edgar@rstudio.com>
Repository: CRAN
Date/Publication: 2018-02-25 23:00:08 UTC
Built: R 3.4.1; ; 2018-09-09 15:17:14 UTC; windows
