# Generated by roxygen2: do not edit by hand

S3method(acceptable_formula,glm)
S3method(acceptable_formula,lm)
S3method(parse_model,glm)
S3method(parse_model,lm)
S3method(parse_model,randomForest)
S3method(print,tidypredict_test)
S3method(tidypredict_fit,data.frame)
S3method(tidypredict_fit,glm)
S3method(tidypredict_fit,lm)
S3method(tidypredict_fit,randomForest)
S3method(tidypredict_interval,data.frame)
S3method(tidypredict_interval,glm)
S3method(tidypredict_interval,lm)
S3method(tidypredict_test,default)
S3method(tidypredict_test,randomForest)
export(acceptable_formula)
export(knit_print.tidypredict_test)
export(parse_model)
export(tidypredict_fit)
export(tidypredict_interval)
export(tidypredict_sql)
export(tidypredict_sql_interval)
export(tidypredict_test)
export(tidypredict_to_column)
import(dplyr)
import(rlang)
import(tidyr)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_df)
importFrom(purrr,reduce)
importFrom(stats,predict)
importFrom(stats,qt)
importFrom(tibble,as.tibble)
importFrom(tibble,rowid_to_column)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(utils,head)
